(***********************************************************************)
(*                                                                     *)
(*                           Htmlc                                     *)
(*                                                                     *)
(*                    Pierre Weis, INRIA Rocquencourt                  *)
(*                                                                     *)
(*  Copyright 1997-2007,                                               *)
(*  Institut National de Recherche en Informatique et en Automatique.  *)
(*  Distributed only by permission.                                    *)
(*                                                                     *)
(***********************************************************************)

(* $Id: debug.mli,v 1.3 2013/05/01 18:37:18 weis Exp $ *)

(** {3 Some simple generic tools for debugging} *)

val get_debug : unit -> bool;;

val set_debug : unit -> unit;;
(** Turn debugging on. *)

val failwith : string -> 'a;;
(** When debugging is on, [Debug.failwith] prints its arguments on [stderr],
    then raises a [Failure] exception. *)

val printf : ('a, out_channel, unit) format -> 'a;;
(** When debugging is on, [Debug.printf] prints its arguments on [stderr]. *)

val message : string -> unit;;
(** When debugging is on, [Debug.message] outputs a given message on [stderr]. *)

val warning : string -> unit;;
(** [Debug.warning] unconditionally outputs a warning on [stderr]. *)

val pause : string -> unit;;
(** When debugging is on, [Debug.pause] outputs outputs a given message on
    [stderr], then stops the program.
    Press return to go on. *)
